import React, { useState } from "react";
import {
  AppBar,
  Toolbar,
  IconButton,
  Typography,
  Box,
  Stack,
  Button,
  Modal,
  Paper,
} from "@mui/material";
import { useHistory } from "react-router-dom";

import { useTranslation } from "react-i18next";
import { Menu, Logout, Translate } from "@mui/icons-material";
import Logo from "../../assets/DSAT_logo.svg";
import { logout } from "../../utils/api";

const style = {
  position: "absolute",
  top: "50%",
  left: "50%",
  transform: "translate(-50%, -50%)",
  width: 300,

  bgcolor: "background.paper",
  boxShadow: 24,
  p: 4,
  textAlign: "center",
  alignItem: "center",
  justifyContent: "center",
};

const Appbar = ({ position, selectedPage, setSelectedPage }) => {
  let history = useHistory();
  const [logoutOpen, setLogoutOpen] = useState(false);
  const { t, i18n } = useTranslation();

  /**
   * The In/ Out Button depends on position of the machine,
   * please refer to api doc
   */
  return (
    <AppBar position="static" color="transparent">
      <Toolbar sx={{ justifyContent: "space-between" }}>
        <Box>
          <img
            style={{
              margin: "auto",
              display: "block",
              height: "50px",
            }}
            src={Logo}
            alt="logo"
          />
        </Box>
        <Stack spacing={2} direction="row">
          {position === "in" ? (
            <Button
              variant={selectedPage === "in" ? "contained" : "outlined"}
              onClick={() => {
                setSelectedPage("in");
              }}
            >
              {t("inManage")}
            </Button>
          ) : (
            <Button
              variant={selectedPage === "out" ? "contained" : "outlined"}
              onClick={() => {
                setSelectedPage("out");
              }}
            >
              {t("outManage")}
            </Button>
          )}
          <Button
            variant={selectedPage === "stat" ? "contained" : "outlined"}
            onClick={() => {
              setSelectedPage("stat");
            }}
          >
            {t("stat")}
          </Button>
        </Stack>
        <Box>
          <IconButton
            sx={{ marginRight: 4 }}
            onClick={() => {
              i18n.changeLanguage(i18n.language === "tc" ? "pt" : "tc");
            }}
          >
            <Translate />
          </IconButton>
          <Button
            variant="contained"
            endIcon={<Logout />}
            onClick={() => {
              setLogoutOpen(true);
            }}
          >
            {t("logoutTitle")}
          </Button>
        </Box>
      </Toolbar>
      <Modal
        open={logoutOpen}
        onClose={() => {
          setLogoutOpen(false);
        }}
        aria-labelledby="modal-modal-title"
        aria-describedby="modal-modal-description"
      >
        <Paper sx={style}>
          <Typography id="modal-modal-title" variant="h6" component="h2">
            {t("logoutText")}
          </Typography>
          <Button
            variant="contained"
            sx={{ margin: 2 }}
            onClick={async () => {
              await logout();
              history.replace("/");
            }}
          >
            {t("confirm")}
          </Button>
          <Button
            sx={{ margin: 2 }}
            variant="contained"
            color="error"
            onClick={() => {
              setLogoutOpen(false);
            }}
          >
            {t("cancel")}
          </Button>
        </Paper>
      </Modal>
    </AppBar>
  );
};

export default Appbar;
