import React, { useEffect, useState, useMemo } from "react";
import {
  FormControl,
  FormControlLabel,
  Table,
  Radio,
  RadioGroup,
  FormLabel,
  TableBody,
  TableCell,
  TableContainer,
  TableHead,
  TableRow,
  Paper,
} from "@mui/material";
import { useTranslation } from "react-i18next";
import moment from "moment";

export const VehicleTypeRadio = ({ value, setValue }) => {
  const { t } = useTranslation();
  return (
    <FormControl component="fieldset">
      <FormLabel component="legend">{t("vehicleType")}</FormLabel>
      <RadioGroup
        row
        aria-label="vehicleType"
        name="row-radio-buttons-group"
        defaultValue="L"
        value={value}
        onChange={(event) => {
          setValue(event.target.value);
        }}
      >
        <FormControlLabel
          value="L"
          control={<Radio />}
          label={t("privateCar")}
        />
        <FormControlLabel value="A" control={<Radio />} label={t("motor")} />
      </RadioGroup>
    </FormControl>
  );
};

export const BookingTypeRadio = ({ value, setValue }) => {
  const { t } = useTranslation();

  return (
    <FormControl component="fieldset">
      <FormLabel component="legend">{t("bookingType")}</FormLabel>
      <RadioGroup
        row
        aria-label="bookingType"
        name="row-radio-buttons-group"
        defaultValue="N"
        value={value}
        onChange={(event) => {
          setValue(event.target.value);
        }}
      >
        <FormControlLabel value="N" control={<Radio />} label={t("methodN")} />
        <FormControlLabel value="D" control={<Radio />} label={t("methodD")} />
        <FormControlLabel value="V" control={<Radio />} label={t("methodV")} />
        <FormControlLabel value="O" control={<Radio />} label={t("methodO")} />
      </RadioGroup>
    </FormControl>
  );
};

export const TableView = ({ data }) => {
  const { t } = useTranslation();
  const [rows, setRows] = useState([]);

  function createData(
    bookingType,
    inTime,
    vehicleType,
    plateId,
    suggestParkingZone,
    inspectTime,
    checkinTime,
    openType
  ) {
    return {
      bookingType,
      inTime,
      vehicleType,
      plateId,
      suggestParkingZone,
      inspectTime,
      checkinTime,
      openType,
    };
  }

  useMemo(() => {
    if (data?.length >= 0) {
      setRows(
        data.map((el) => {
          return {
            bookingType: el.bookingType,
            inTime: el.entryTime,
            vehicleType: el.vehType,
            plateId: el.plateNo,
            suggestParkingZone: el.parkingName,
            inspectTime: el.bookingTime,
            checkinTime: el.checkInTime,
            openType: el.openType,
          };
        })
      );
    }
  }, [data]);

  return (
    <TableContainer component={Paper}>
      <Table sx={{ minWidth: 650 }} aria-label="simple table" size="small">
        <TableHead>
          <TableRow>
            <TableCell align="center" style={{ border: "1px solid" }}>
              {t("bookingType")}
            </TableCell>
            <TableCell align="center" style={{ border: "1px solid" }}>
              {t("inTime")}
            </TableCell>
            <TableCell align="center" style={{ border: "1px solid" }}>
              {t("vehicleType")}
            </TableCell>
            <TableCell align="center" style={{ border: "1px solid" }}>
              {t("plateId")}
            </TableCell>
            <TableCell align="center" style={{ border: "1px solid" }}>
              {t("suggestParkingZone")}
            </TableCell>
            <TableCell align="center" style={{ border: "1px solid" }}>
              {t("inspectTime")}
            </TableCell>
            <TableCell align="center" style={{ border: "1px solid" }}>
              {t("checkinTime")}
            </TableCell>
            <TableCell align="center" style={{ border: "1px solid" }}>
              {t("openType")}
            </TableCell>
          </TableRow>
        </TableHead>
        <TableBody>
          {rows.map((row) => (
            <TableRow
              key={row.name}
              sx={{ "&:last-child td, &:last-child th": { border: 0 } }}
            >
              <TableCell
                component="th"
                scope="row"
                align="center"
                style={{ border: "1px solid" }}
              >
                {row.bookingType || "-"}
              </TableCell>
              <TableCell align="center" style={{ border: "1px solid" }}>
                {row.inTime || "-"}
              </TableCell>
              <TableCell align="center" style={{ border: "1px solid" }}>
                {row.vehicleType || "-"}
              </TableCell>
              <TableCell align="center" style={{ border: "1px solid" }}>
                {row.plateId || "-"}
              </TableCell>
              <TableCell align="center" style={{ border: "1px solid" }}>
                {row.suggestParkingZone || "-"}
              </TableCell>
              <TableCell align="center" style={{ border: "1px solid" }}>
                {row.inspectTime || "-"}
              </TableCell>
              <TableCell align="center" style={{ border: "1px solid" }}>
                {row.checkinTime || "-"}
              </TableCell>
              <TableCell align="center" style={{ border: "1px solid" }}>
                {row.openType || "-"}
              </TableCell>
            </TableRow>
          ))}
        </TableBody>
      </Table>
    </TableContainer>
  );
};
