import React, { useState, useEffect } from "react";
import { withRouter, useHistory } from "react-router-dom";
import {
  Grid,
  Button,
  FormControl,
  InputLabel,
  Input,
  InputAdornment,
  IconButton,
  Alert,
  Switch,
  Typography,
  Stack,
  Dialog,
  DialogActions,
  DialogTitle,
  TextField,
  DialogContent,
  DialogContentText,
} from "@mui/material";
import Visibility from "@mui/icons-material/Visibility";
import VisibilityOff from "@mui/icons-material/VisibilityOff";
import { useTranslation } from "react-i18next";
import Logo from "../../assets/DSAT_logo.svg";
import { login } from "../../utils/api";

const Login = ({ gateLocation, setGateLocation }) => {
  let history = useHistory();
  const { t } = useTranslation();
  const [username, setUsername] = useState("");
  const [password, setPassword] = useState("");
  const [showPassword, setShowPassword] = useState(false);
  const [loginError, setLoginError] = useState(false);
  const [settingPageOpen, setSettingPageOpen] = useState(false);
  const [apiUrl, setApiUrl] = useState("");
  const [gateId, setGateId] = useState("");
  const [machineId, setMachineId] = useState("");

  /**
   * TODO: Add a modal for api url configuration.
   * Please refer to dsat_app
   * e.g. our apiurl and ATOS's VICS api url
   */

  const attemptLogin = async () => {
    /**
     *  TODO: please refer dsat_api, for setting the API URL, etc.
     */
    const loginResult = await login({
      userId: username,
      password,
      machineType: "G",
      machineId,
      apiUrl,
    });
    if (loginResult) {
      if (loginResult.userId === "administrator") {
        handleClickOpen();
      } else if (!!loginResult.userId) {
        localStorage.setItem("username", username);
        localStorage.setItem("@password", password);
        localStorage.setItem("@centerCode", loginResult.centerCode);
        localStorage.setItem("@sessionId", loginResult.sessionId[0].split(';')[0]);
        history.push("/dashboard");
      } else {
        setLoginError(true);
      }
    } else {
      setLoginError(true);
    }
  };

  const handleClickOpen = () => {
    setSettingPageOpen(true);
  };

  const handleClose = () => {
    setSettingPageOpen(false);
  };

  const handleSubmit = () => {
    localStorage.setItem("@apiUrl", apiUrl);
    localStorage.setItem("@gateId", gateId);
    localStorage.setItem("@machineId", machineId);

    setSettingPageOpen(false);
  };

  useEffect(() => {
    const init = () => {
      setApiUrl(localStorage.getItem("@apiUrl"));
      setMachineId(localStorage.getItem("@machineId"));
      setGateId(localStorage.getItem("@gateId"));
    };
    init();
  }, []);

  return (
    <div>
      <Grid
        container
        spacing={0}
        direction="column"
        alignItems="center"
        justifyContent="center"
        style={{ minHeight: "100vh" }}
      >
        <Grid
          item
          xs={3}
          container
          direction="column"
          alignItems="center"
          justifyContent="center"
          spacing={2}
        >
          <Grid
            item
            container
            alignItems="center"
            justifyContent="center"
            spacing={2}
          >
            <Grid item>
              <img
                style={{
                  margin: "auto",
                  display: "block",
                  height: "50px",
                }}
                src={Logo}
                alt="logo"
              />
            </Grid>
            <Grid item>{t("gateMain")}</Grid>
          </Grid>
          {loginError && (
            <Grid item xs>
              <Alert severity="error">{t("cannotLogin")}</Alert>
            </Grid>
          )}
          <Grid item xs>
            <FormControl sx={{ m: 1, width: "25ch" }} variant="standard">
              <InputLabel htmlFor="standard-adornment-username">
                {t("username")}
              </InputLabel>
              <Input
                id="standard-adornment-username"
                type="text"
                value={username}
                onChange={(event) => {
                  setUsername(event.target.value);
                }}
              />
            </FormControl>
          </Grid>
          <Grid item xs>
            <FormControl sx={{ m: 1, width: "25ch" }} variant="standard">
              <InputLabel htmlFor="standard-adornment-password">
                {t("password")}
              </InputLabel>
              <Input
                id="standard-adornment-password"
                type={showPassword ? "text" : "password"}
                value={password}
                onChange={(event) => {
                  setPassword(event.target.value);
                }}
                endAdornment={
                  <InputAdornment position="end">
                    <IconButton
                      aria-label="toggle password visibility"
                      onClick={() => {
                        setShowPassword(!showPassword);
                      }}
                      onMouseDown={(event) => {
                        event.preventDefault();
                      }}
                    >
                      {showPassword ? <VisibilityOff /> : <Visibility />}
                    </IconButton>
                  </InputAdornment>
                }
              />
            </FormControl>
          </Grid>
          <Grid item xs>
            <Button variant="contained" onClick={attemptLogin}>
              {t("login")}
            </Button>
          </Grid>
        </Grid>
      </Grid>
      <Dialog open={settingPageOpen} onClose={handleClose}>
        <DialogTitle>Setting</DialogTitle>
        <DialogContent>
          <TextField
            autoFocus
            margin="dense"
            id="machineId"
            label="Machine Id"
            type="text"
            fullWidth
            variant="standard"
            value={machineId}
            onChange={(event) => {
              console.log(event.target.value);
              setMachineId(event.target.value);
            }}
          />
          <TextField
            margin="dense"
            id="gate"
            label="Control Gate"
            type="text"
            fullWidth
            variant="standard"
            value={gateId}
            onChange={(event) => {
              console.log(event.target.value);
              setGateId(event.target.value);
            }}
          />
          <TextField
            margin="dense"
            id="apiUrl"
            label="API Url"
            type="text"
            fullWidth
            variant="standard"
            value={apiUrl}
            onChange={(event) => {
              console.log(event.target.value);
              setApiUrl(event.target.value);
            }}
          />
          {/* This is for developemnt only, production should setting this in setting page. */}
          <Stack direction="row" spacing={1} alignItems="center">
            <Typography>離場</Typography>
            <Switch
              checked={gateLocation === "in"}
              onChange={(event) => {
                setGateLocation(event.target.checked ? "in" : "out");
              }}
            />
            <Typography>進場</Typography>
          </Stack>
        </DialogContent>
        <DialogActions>
          <Button onClick={handleClose}>Cancel</Button>
          <Button onClick={handleSubmit}>Sumbit</Button>
        </DialogActions>
      </Dialog>
    </div>
  );
};

export default withRouter(Login);
