import React, { useEffect, useState } from "react";
import { Grid, Box, TextField, Button, Stack, Typography } from "@mui/material";
import { useTranslation } from "react-i18next";
import DesktopDatePicker from "@mui/lab/DesktopDatePicker";
import TimePicker from "@mui/lab/TimePicker";
import moment from "moment";
import { getLogs } from "../../utils/api";
import {
  VehicleTypeRadio,
  BookingTypeRadio,
  TableViewIn,
  TableViewOut,
} from "./component";

const Stat = ({ gateLocation }) => {
  const { t } = useTranslation();
  const [plate, setPlate] = useState("");
  const [date, setDate] = useState(moment());
  const [openStartTime, setOpenStartTime] = useState(moment().startOf("day"));
  const [openEndTime, setOpenEndTime] = useState(moment().endOf("day"));
  const [inspectStartTime, setinspectStartTime] = useState(
    moment().startOf("day")
  );
  const [inspectEndTime, setinspectEndTime] = useState(moment().endOf("day"));

  const [data, setData] = useState([]);

  useEffect(() => {
    const init = async () => {
      const result = await getLogs({
        machineId: localStorage.getItem("machineId"),
        limit: 10,
      });
      // console.log(result);
      setData(result);
    };
    init();
  }, []);

  const query = async () => {
    const result = await getLogs({
      machineId: localStorage.getItem("machineId"),
      limit: 10,
      plateId: plate,
      date: moment(date).format("YYYY-MM-DD"),
      openStartTime: moment(openStartTime).format("HH:mm:ss"),
      openEndTime: moment(openEndTime).format("HH:mm:ss"),
      inspectStartTime: moment(inspectStartTime).format("HH:mm:ss"),
      inspectEndTime: moment(inspectEndTime).format("HH:mm:ss"),
    });
    // console.log(result);
    setData(result);
    // console.log(
    //   plate,
    //   date,
    //   openStartTime,
    //   openEndTime,
    //   inspectStartTime,
    //   inspectEndTime
    // );
  };

  return (
    <Stack>
      <Grid container>
        <Grid item xs={5} sx={{ padding: 2 }}>
          <Stack spacing={2}>
            <Stack direction="row" alignItems="center" spacing={1}>
              <Typography>
                {`　　`}
                {t("date")}
              </Typography>
              <DesktopDatePicker
                inputFormat="DD/MM/YYYY"
                value={date}
                onChange={(value) => setDate(value)}
                renderInput={(params) => (
                  <TextField {...params} size="small" sx={{ width: 150 }} />
                )}
              />
            </Stack>
            <Stack direction="row" alignItems="center" spacing={1}>
              <Typography>{t("openPeriod")}</Typography>
              <TimePicker
                size="small"
                value={openStartTime}
                onChange={(value) => setOpenStartTime(value)}
                renderInput={(params) => (
                  <TextField {...params} size="small" sx={{ width: 150 }} />
                )}
              />
              <Typography> - </Typography>
              <TimePicker
                value={openEndTime}
                onChange={(value) => setOpenEndTime(value)}
                renderInput={(params) => (
                  <TextField {...params} size="small" sx={{ width: 150 }} />
                )}
              />
            </Stack>
          </Stack>
        </Grid>
        <Grid item xs={5} sx={{ padding: 2 }}>
          <Stack spacing={2}>
            <Stack direction="row" alignItems="center" spacing={1}>
              <Typography>{t("plateId")}</Typography>
              <TextField
                id="outlined-basic"
                label={t("inputPlate")}
                variant="outlined"
                size="small"
                value={plate}
                onChange={(event) => setPlate(event.target.value)}
              />
            </Stack>
            {gateLocation === "in" && (
              <Stack direction="row" alignItems="center" spacing={1}>
                <Typography>{t("inspectTime")}</Typography>
                <TimePicker
                  value={inspectStartTime}
                  onChange={(value) => {
                    setinspectStartTime(value);
                  }}
                  renderInput={(params) => (
                    <TextField {...params} size="small" sx={{ width: 150 }} />
                  )}
                />
                <Typography> - </Typography>
                <TimePicker
                  value={inspectEndTime}
                  onChange={(value) => setinspectEndTime(value)}
                  renderInput={(params) => (
                    <TextField {...params} size="small" sx={{ width: 150 }} />
                  )}
                />
              </Stack>
            )}
          </Stack>
        </Grid>
        <Grid item xs sx={{ margin: 2 }}>
          <Button size="large" variant="contained" onClick={query}>
            {t("query")}
          </Button>
        </Grid>
      </Grid>
      <Grid item xs>
        {gateLocation === "in" ? (
          <TableViewIn data={data} />
        ) : (
          <TableViewOut data={data} />
        )}
      </Grid>
    </Stack>
  );
};

export default Stat;
