import { isArray } from "lodash";

// const apiUrl = "http://203.186.131.118:5001";
// const apiUrl = "http://192.168.3.212:3001";
const apiUrl = "http://localhost:3001";
const dsatApiUrl = localStorage.getItem("@apiUrl");

const constructParams = (params) => {
  let query = ``;
  if (params) {
    Object.entries(params).forEach(([key, value], index) => {
      if (isArray(value) && value.length > 0) {
        value.map((ele, valIndex) => {
          if (index === 0 && valIndex === 0) {
            query += `${key}=${ele}`;
          } else {
            query += `&${key}=${ele}`;
          }
        });
      } else {
        if (index == 0) {
          query += `${key}=${value}`;
        } else {
          query += `&${key}=${value}`;
        }
      }
    });
  }
  return query;
};

export const login = async (payload) => {
  try {
    const result = await fetch(`${apiUrl}/login`, {
      method: "POST",
      mode: "cors",
      headers: {
        "Content-Type": "application/json",
      },
      body: JSON.stringify(payload),
    }).then((res) => res.json());
    return result.data;
  } catch (err) {
    console.log("err", err);
  }
};

export const logout = async () => {
  try {
    await fetch(`${apiUrl}/logout`, {
      method: "GET",
      headers: {
        "Content-Type": "application/json",
      },
    });
    localStorage.setItem("username", null);
  } catch (err) {
    console.error("err: ", err);
  }
};

export const getBookingType = () => {};

export const checkEntry = async (plateNo, vehCat, bookingType) => {
  const sessionId = localStorage.getItem("@sessionId");
  const machineId = localStorage.getItem("@machineId");
  const centerCode = localStorage.getItem("@centerCode");
  try {
    const result = await fetch(`${apiUrl}/checkIn`, {
      method: "POST",
      mode: "cors",
      headers: {
        "Content-Type": "application/json",
      },
      body: JSON.stringify({
        plateNo, vehCat, bookingType, centerCode, machineId, apiUrl: dsatApiUrl, sessionId
      })
    })
    .then((res) => res.json());
    return result.data;
  } catch (err) {
    console.log("err", err);
  }
};

export const entryByManual = async (plateNo, vehCat, bookingType) => {
  const sessionId = localStorage.getItem("@sessionId");
  const machineId = localStorage.getItem("@machineId");
  const centerCode = localStorage.getItem("@centerCode");
  try {
    const result = await fetch(`${apiUrl}/manualOpen`, {
      method: "POST",
      mode: "cors",
      headers: {
        "Content-Type": "application/json",
      },
      body: JSON.stringify({
        plateNo, vehCat, bookingType, centerCode, machineId, apiUrl: dsatApiUrl, sessionId
      })
    }).then((res) => res.json());
    return result.data;
  } catch (err) {
    console.log("err", err);
  }
};

export const checkOut = () => {};

export const openGate = async () => {
  const sessionId = localStorage.getItem("@sessionId");
  const params = constructParams({
    apiUrl: dsatApiUrl,
    sessionId
  })
  try {
    const result = await fetch(`${apiUrl}/openGate?${params}`, {
      method: "GET",
      mode: "cors",
      headers: {
        "Content-Type": "application/json",
      },
    }).then((res) => res.json());
    return result.data;
  } catch (err) {
    console.log("err", err);
  }
};

export const closeGate = async () => {
  const sessionId = localStorage.getItem("@sessionId");
  const params = constructParams({
    apiUrl: dsatApiUrl,
    sessionId
  })
  try {
    const result = await fetch(`${apiUrl}/closeGate?${params}`, {
      method: "GET",
      mode: "cors",
      headers: {
        "Content-Type": "application/json",
      },
    }).then((res) => res.json());
    return result.data;
  } catch (err) {
    console.log("err", err);
  }
};

export const getLogs = async (payload) => {
  return [
    {
    "vehType":"L",
    "vehTypeDesc":"Auto. Ligeiro - 輕型汽車",
    "plateNo":"MA-12-34",
    "centerCode":"CIVA",
    "parkingName":"B",
    "bookingTime":"2021-08-12 15:00:00-16:00:00",
    "checkInTime":"2021-08-12 15:00:00",
    "bookingType":"N",
    "entryTime":"2021-08-12 15:06:00",
    "openType":"A",
    "openTime":"2021-08-12 15:06:00"
    },
    {
    "vehType":"L",
    "vehTypeDesc":"Auto. Ligeiro - 輕型汽車",
    "plateNo":"MA-12-35",
    "centerCode":"CIVA",
    "parkingName":"B",
    "bookingTime":"2021-08-12 15:00:00-16:00:00",
    "checkInTime":"2021-08-12 15:00:00",
    "bookingType":"N",
    "entryTime":"2021-08-12 15:06:00",
    "openType":"A",
    "openTime":"2021-08-12 15:06:00"
    }
    ];
    
  try {
    const result = await fetch(
      `${apiUrl}/log?${constructParams(payload)}`
    ).then((res) => res.json());
    return result.data;
  } catch (err) {
    console.error("err", err);
  }
};

export const exit = async (plateNo, vehCat) => {
  const sessionId = localStorage.getItem("@sessionId");
  const machineId = localStorage.getItem("@machineId");
  try {
    const result = await fetch(`${apiUrl}/exit`, {
      method: "POST",
      mode: "cors",
      headers: {
        "Content-Type": "application/json",
      },
      body: JSON.stringify({
        plateNo, vehCat, machineId, apiUrl: dsatApiUrl, sessionId
      })
    }).then((res) => res.json());
    return result.data;
  } catch (err) {
    console.log("err", err);
  }
};

export const getOpenList = async (openDate) => {
  const sessionId = localStorage.getItem("@sessionId");
  const machineId = localStorage.getItem("@machineId");
  const params = constructParams({
    machineId,
    openDate,
    length: 5,
    apiUrl: dsatApiUrl,
    sessionId
  });
  try {
    const result = await fetch(`${apiUrl}/getOpenList?${params}`, {
      method: "GET",
      // headers: {
      //   "Content-Type": "application/json",
      // }
    }).then(res => res.json());
    return result.data.data;
  } catch (err) {
    console.error("getOpenList err: ", err);
  }
}